==> cert_creation-1.7.8-sources.jar: com/xdja/safeclient/certcreation/activity/ActivityPath.java <==
package com.xdja.safeclient.certcreation.activity;

/**
 * 所有的activity路径至少有两层/结构，否则会报错
 * Created by zjc on 2018/12/14 0014.
 */

public class ActivityPath {

    public static final String ACTIVITY_SETTING = "/cert/setting";

    public static final String NAME_SETTING = "设置";

    public static final String ACTIVITY_PHONE_INFO = "/cert/phone_info";

    public static final String NAME_PHONE_INFO = "输入手机号";

    public static final String ACTIVITY_SELFIE = "/cert/selfie";

    public static final String NAME_SELFIE = "自拍照";

    public static final String ACTIVITY_CAMERA_READY = "/cert/camera_ready";

    public static final String NAME_CAMERA_READY = "持证拍照准备";

    public static final String ACTIVITY_CAMERA_ID_READY = "/cert/id_ready";

    public static final String NAME_ID_READY = "上传身份证照片";

    public static final String ACTIVITY_BASIC_INFO = "/cert/basic_info";

    public static final String NAME_BASIC_INFO = "基本信息";

    public static final String ACTIVITY_PROFESSION = "/cert/profession";

    public static final String NAME_PROFESSION = "完善职业信息";

    public static final String ACTIVITY_REASON = "/cert/reason";

    public static final String NAME_REASON = "原因";

    public static final String ACTIVITY_UPDATE_CERT = "/cert/update";

    public static final String NAME_UPDATE_CERT = "更新证书信息";

    public static final String ACTIVITY_AUTH_FAIL = "/cert/auth_fail";

    public static final String NAME_AUTH_FAIL = "实体认证失败";

    public static final String ACTIVITY_OCR_YUNCONG_RESULT = "/cert/ocr_yuncong";

    public static final String NAME_OCR_YUNCONG_RESULT = "云从OCR结果";

    public static final String ACTIVITY_CERT_DETAIL_INFO = "/cert/cert_detail_info";

    public static final String NAME_CERT_DETAIL_INFO = "证书详情";

    public static final String ACTIVITY_NFC_YISHU = "/cert/nfc_yishu";

    public static final String NAME_NFC_YISHU = "亿数NFC";

    public static final String ACTIVITY_CONFIG_STEP1 = "/cert/config_step1";

    public static final String NAME_CONFIG_STEP1 = "第一个配置界面";

    public static final String ACTIVITY_CONFIG_STEP2 = "/cert/config_step2";

    public static final String NAME_CONFIG_STEP2 = "第二个配置界面";

    public static final String ACTIVITY_CONFIG_STEP3 = "/cert/config_step3";

    public static final String NAME_CONFIG_STEP3 = "第三个配置界面";

    public static final String ACTIVITY_YUNCONG_LIVE_START = "/cert/yuncong/live";

    public static final String NAME_YUNCONG_LIVE_START = "云从人脸识别开始";

    public static final String ACTIVITY_CHOOSE_IDENTIFY_TYPE = "/cert/choose_bind_way";

    public static final String NAME_CHOOSE_IDENTIFY_TYPE = "选择身份认证方式";

    public static final String ACTIVITY_XDJA_NFC = "/cert/xdja_nfc";

    public static final String NANE_XDJA_NFC = "信大捷安NFC";

    public static final String ACTIVITY_XDJA_ID_RESULT = "/cert/xdja_id_result";

    public static final String NAME_XDJA_ID_RESULT = "信大捷安身份证结果";

    public static final String ACTIVITY_YUNCONG_OCR = "/cert/yuncong_ocr";

    public static final String NAME_YUNCONG_OCR = "云从OCR";


}

==> cert_creation-1.8.0_8-sources.jar: com/xdja/safeclient/certcreation/activity/ActivityPath.java <==
package com.xdja.safeclient.certcreation.activity;

/**
 * 所有的activity路径至少有两层/结构，否则会报错
 * Created by zjc on 2018/12/14 0014.
 */

public class ActivityPath {

    public static final String ACTIVITY_SETTING = "/cert/setting";

    public static final String NAME_SETTING = "设置";

    public static final String ACTIVITY_PHONE_INFO = "/cert/phone_info";

    public static final String NAME_PHONE_INFO = "输入手机号";

    public static final String ACTIVITY_PHONE_APPLY_CERT = "/cert/phone_apply_cert";

    public static final String NAME_PHONE_APPLY_CERT = "输入手机号发证";

    public static final String ACTIVITY_SELFIE = "/cert/selfie";

    public static final String NAME_SELFIE = "自拍照";

    public static final String ACTIVITY_CAMERA_READY = "/cert/camera_ready";

    public static final String NAME_CAMERA_READY = "持证拍照准备";

    public static final String ACTIVITY_CAMERA_ID_READY = "/cert/id_ready";

    public static final String NAME_ID_READY = "上传身份证照片";

    public static final String ACTIVITY_BASIC_INFO = "/cert/basic_info";

    public static final String NAME_BASIC_INFO = "基本信息";

    public static final String ACTIVITY_PROFESSION = "/cert/profession";

    public static final String NAME_PROFESSION = "完善职业信息";

    public static final String ACTIVITY_REASON = "/cert/reason";

    public static final String NAME_REASON = "原因";

    public static final String ACTIVITY_UPDATE_CERT = "/cert/update";

    public static final String NAME_UPDATE_CERT = "更新证书信息";

    public static final String ACTIVITY_AUTH_FAIL = "/cert/auth_fail";

    public static final String NAME_AUTH_FAIL = "实体认证失败";

    public static final String ACTIVITY_OCR_YUNCONG_RESULT = "/cert/ocr_yuncong";

    public static final String NAME_OCR_YUNCONG_RESULT = "云从OCR结果";

    public static final String ACTIVITY_CERT_DETAIL_INFO = "/cert/cert_detail_info";

    public static final String NAME_CERT_DETAIL_INFO = "证书详情";

    public static final String ACTIVITY_NFC_YISHU = "/cert/nfc_yishu";

    public static final String NAME_NFC_YISHU = "亿数NFC";

    public static final String ACTIVITY_CONFIG_STEP1 = "/cert/config_step1";

    public static final String NAME_CONFIG_STEP1 = "第一个配置界面";

    public static final String ACTIVITY_CONFIG_STEP2 = "/cert/config_step2";

    public static final String NAME_CONFIG_STEP2 = "第二个配置界面";

    public static final String ACTIVITY_CONFIG_STEP3 = "/cert/config_step3";

    public static final String NAME_CONFIG_STEP3 = "第三个配置界面";

    public static final String ACTIVITY_YUNCONG_LIVE_START = "/cert/yuncong/live";

    public static final String NAME_YUNCONG_LIVE_START = "云从人脸识别开始";

    public static final String ACTIVITY_CHOOSE_IDENTIFY_TYPE = "/cert/choose_bind_way";

    public static final String NAME_CHOOSE_IDENTIFY_TYPE = "选择身份认证方式";

    public static final String ACTIVITY_XDJA_NFC = "/cert/xdja_nfc";

    public static final String NANE_XDJA_NFC = "信大捷安NFC";

    public static final String ACTIVITY_XDJA_ID_RESULT = "/cert/xdja_id_result";

    public static final String NAME_XDJA_ID_RESULT = "信大捷安身份证结果";

    public static final String ACTIVITY_YUNCONG_OCR = "/cert/yuncong_ocr";

    public static final String NAME_YUNCONG_OCR = "云从OCR";


}
